@@ -177,8 +177,8 @@ public:
 	{
 		if(i->result)
 			return;
-		QByteArray cs = s.toUtf8();
-		int len = cs.length();
+		const QByteArray cs = s.toUtf8();
+		const int len = cs.length();
 		char *p = new char[len+1];
 		memcpy(p, cs.data(), len);
 		p[len] = 0;
@@ -204,7 +204,7 @@ static QByteArray makeByteArray(const void *in, unsigned int len)
 
 static QString addrString(const SASLContext::HostPort &hp)
 {
-	return (hp.addr + ';' + QString::number(hp.port));
+	return (hp.addr + QLatin1Char(';') + QString::number(hp.port));
 }
 
 //----------------------------------------------------------------------------
@@ -365,8 +365,8 @@ private:
 	static int scb_checkauth(sasl_conn_t *, void *context, const char *requested_user, unsigned, const char *auth_identity, unsigned, const char *, unsigned, struct propctx *)
 	{
 		saslContext *that = (saslContext *)context;
-		that->sc_username = auth_identity; // yeah yeah, it looks
-		that->sc_authzid = requested_user; // backwards, but it is right
+		that->sc_username = QString::fromLatin1(auth_identity); // yeah yeah, it looks
+		that->sc_authzid = QString::fromLatin1(requested_user); // backwards, but it is right
 		that->ca_flag = true;
 		return SASL_OK;
 	}
@@ -395,7 +395,7 @@ private:
 
 				params.applyInteract(need);
 				if(params.missingAny()) {
-					out_mech = m;
+					out_mech = QString::fromLatin1(m);
 					result_result = Params;
 					return;
 				}
@@ -406,7 +406,7 @@ private:
 				return;
 			}
 
-			out_mech = m;
+			out_mech = QString::fromLatin1(m);
 			if(in_sendFirst && clientout) {
 				out_buf = makeByteArray(clientout, clientoutlen);
 				result_haveClientInit = true;
@@ -470,7 +470,7 @@ private:
 				const char *serverout;
 				unsigned int serveroutlen;
 				ca_flag = false;
-				int r = sasl_server_start(con, in_mech.toLatin1().data(), clientin, clientinlen, &serverout, &serveroutlen);
+				const int r = sasl_server_start(con, in_mech.toLatin1().data(), clientin, clientinlen, &serverout, &serveroutlen);
 				if(r != SASL_OK && r != SASL_CONTINUE) {
 					setAuthCondition(r);
 					result_result = Error;
@@ -500,7 +500,7 @@ private:
 			if(!ca_skip) {
 				const char *serverout;
 				unsigned int serveroutlen;
-				int r = sasl_server_step(con, in_buf.data(), in_buf.size(), &serverout, &serveroutlen);
+				const int r = sasl_server_step(con, in_buf.data(), in_buf.size(), &serverout, &serveroutlen);
 				if(r != SASL_OK && r != SASL_CONTINUE) {
 					setAuthCondition(r);
 					result_result = Error;
@@ -554,7 +554,7 @@ private:
 				r = sasl_decode(con, in.data() + at, size, &outbuf, &len);
 			if(r != SASL_OK)
 				return false;
-			int oldsize = out->size();
+			const int oldsize = out->size();
 			out->resize(oldsize + len);
 			memcpy(out->data() + oldsize, outbuf, len);
 			at += size;
@@ -650,7 +650,7 @@ public:
 
 		result_result = Error;
 
-		int r = sasl_client_new(service.toLatin1().data(), host.toLatin1().data(), localAddr.isEmpty() ? nullptr : localAddr.toLatin1().data(), remoteAddr.isEmpty() ? nullptr : remoteAddr.toLatin1().data(), callbacks, 0, &con);
+		const int r = sasl_client_new(service.toLatin1().data(), host.toLatin1().data(), localAddr.isEmpty() ? nullptr : localAddr.toLatin1().data(), remoteAddr.isEmpty() ? nullptr : remoteAddr.toLatin1().data(), callbacks, 0, &con);
 		if(r != SASL_OK) {
 			setAuthCondition(r);
 			doResultsReady();
@@ -713,7 +713,7 @@ public:
 		r = sasl_listmech(con, nullptr, nullptr, " ", nullptr, &ml, nullptr, nullptr);
 		if(r != SASL_OK)
 			return;
-		result_mechlist = QString::fromUtf8(ml).split(' ');
+		result_mechlist = QString::fromUtf8(ml).split(QLatin1Char(' '));
 
 		servermode = true;
 		step = 0;
@@ -739,7 +739,7 @@ public:
 
 	SASL::Params clientParams() const override
 	{
-		SASLParams::SParams sparams = params.missing();
+		const SASLParams::SParams sparams = params.missing();
 		return SASL::Params(sparams.user, sparams.authzid, sparams.pass, sparams.realm);
 	}
 
@@ -856,7 +856,7 @@ public:
 
 	QByteArray to_net() override
 	{
-		QByteArray a = result_to_net;
+		const QByteArray a = result_to_net;
 		result_to_net.clear();
 		return a;
 	}
@@ -868,7 +868,7 @@ public:
 
 	QByteArray to_app() override
 	{
-		QByteArray a = result_plain;
+		const QByteArray a = result_plain;
 		result_plain.clear();
 		return a;
 	}
