@@ -157,7 +157,7 @@ void GpgOp::Private::act_needCard()
 
 void GpgOp::Private::act_readyReadDiagnosticText()
 {
-	QString s = act->readDiagnosticText();
+	const QString s = act->readDiagnosticText();
 	//printf("dtext ready: [%s]\n", qPrintable(s));
 	diagnosticText += s;
 
@@ -195,13 +195,13 @@ void GpgOp::Private::act_finished()
 
 	if(output.wasSigned)
 	{
-		const char *s;
+		QString s;
 		if(output.verifyResult == GpgOp::VerifyGood)
-			s = "VerifyGood";
+			s = QStringLiteral("VerifyGood");
 		else if(output.verifyResult == GpgOp::VerifyBad)
-			s = "VerifyBad";
+			s = QStringLiteral("VerifyBad");
 		else
-			s = "VerifyNoKey";
+			s = QStringLiteral("VerifyNoKey");
 		diagnosticText += QStringLiteral("wasSigned: verifyResult: %1\n").arg(s);
 	}
 
@@ -396,7 +396,7 @@ QByteArray GpgOp::read()
 	}
 	else
 	{
-		QByteArray a = d->result;
+		const QByteArray a = d->result;
 		d->result.clear();
 		return a;
 	}
