@@ -105,8 +105,8 @@ public:
 		_externalConfig = false;
 		_streamLogger = nullptr;
 
-		QByteArray level = qgetenv ("QCALOGGER_LEVEL");
-		QByteArray file = qgetenv ("QCALOGGER_FILE");
+		const QByteArray level = qgetenv ("QCALOGGER_LEVEL");
+		const QByteArray file = qgetenv ("QCALOGGER_FILE");
 
 		if (!level.isEmpty ()) {
 			printf ("XXXX %s %s\n", level.data (), file.data ());
@@ -156,9 +156,9 @@ public:
 	defaultConfig () const override {
 		QVariantMap mytemplate;
 
-		mytemplate[QStringLiteral("formtype")] = "http://affinix.com/qca/forms/qca-logger#1.0";
+		mytemplate[QStringLiteral("formtype")] = QStringLiteral("http://affinix.com/qca/forms/qca-logger#1.0");
 		mytemplate[QStringLiteral("enabled")] = false;
-		mytemplate[QStringLiteral("file")] = "";
+		mytemplate[QStringLiteral("file")] = QLatin1String("");
 		mytemplate[QStringLiteral("level")] = (int)Logger::Quiet;
 
 		return mytemplate;
