@@ -247,7 +247,7 @@ public:
 
 	QByteArray
 	endSign () override {
-		QByteArray r = _privkeySign.signature ();
+		const QByteArray r = _privkeySign.signature ();
 		_privkeySign = PrivateKey ();
 		return r;
 	}
@@ -435,7 +435,7 @@ public:
 						{
 							QFile file (_entry.keyReference);
 							if (file.open (QIODevice::ReadOnly)) {
-								QByteArray contents = file.readAll ();
+								const QByteArray contents = file.readAll ();
 
 								PrivateKey k = PrivateKey::fromDER (
 									contents,
@@ -1047,8 +1047,8 @@ public:
 				PublicType publicType = publicTypeInvalid;
 
 				entry.name = config[QString::asprintf ("entry_%02d_name", i)].toString ();
-				QString stringReferenceType  = config[QString::asprintf ("entry_%02d_private_type", i)].toString ();
-				QString stringPublicType  = config[QString::asprintf ("entry_%02d_public_type", i)].toString ();
+				const QString stringReferenceType  = config[QString::asprintf ("entry_%02d_private_type", i)].toString ();
+				const QString stringPublicType  = config[QString::asprintf ("entry_%02d_public_type", i)].toString ();
 				entry.noPassphrase = config[QString::asprintf ("entry_%02d_no_passphrase", i)].toBool ();
 				entry.unlockTimeout = config[QString::asprintf ("entry_%02d_unlock_timeout", i)].toInt ();
 
@@ -1085,7 +1085,7 @@ public:
 						goto cleanup1;
 					break;
 					case publicTypeX509Chain:
-						QStringList base64certs = config[QString::asprintf ("entry_%02d_public", i)].toString ().split (QStringLiteral("!"));
+						const QStringList base64certs = config[QString::asprintf ("entry_%02d_public", i)].toString ().split (QStringLiteral("!"));
 
 						foreach (const QString &s, base64certs) {
 							entry.chain += Certificate::fromDER (
@@ -1180,7 +1180,7 @@ private:
 
 		entry = SoftStoreEntry ();
 
-		QStringList list = serialized.split (QStringLiteral("/"));
+		const QStringList list = serialized.split (QStringLiteral("/"));
 		int n=0;
 
 		if (list.size () < 8) {
@@ -1285,7 +1285,7 @@ private:
 		QString to;
 
 		foreach (const QChar &c, from) {
-			if (c == '/' || c == '\\') {
+			if (c == QLatin1Char('/') || c == QLatin1Char('\\')) {
 				to += QString::asprintf ("\\x%04x", c.unicode ());
 			}
 			else {
@@ -1305,7 +1305,7 @@ private:
 		for (int i=0;i<from.size ();i++) {
 			QChar c = from[i];
 
-			if (c == '\\') {
+			if (c == QLatin1Char('\\')) {
 				to += QChar ((ushort)from.midRef (i+2, 4).toInt (nullptr, 16));
 				i+=5;
 			}
@@ -1406,14 +1406,14 @@ public:
 			Logger::Debug
 		);
 
-		mytemplate[QStringLiteral("formtype")] = "http://affinix.com/qca/forms/qca-softstore#1.0";
+		mytemplate[QStringLiteral("formtype")] = QStringLiteral("http://affinix.com/qca/forms/qca-softstore#1.0");
 		for (int i=0;i<_CONFIG_MAX_ENTRIES;i++) {
 			mytemplate[QString::asprintf ("entry_%02d_enabled", i)] = false;
-			mytemplate[QString::asprintf ("entry_%02d_name", i)] = "";
-			mytemplate[QString::asprintf ("entry_%02d_public_type", i)] = "";
-			mytemplate[QString::asprintf ("entry_%02d_private_type", i)] = "";
-			mytemplate[QString::asprintf ("entry_%02d_public", i)] = "";
-			mytemplate[QString::asprintf ("entry_%02d_private", i)] = "";
+			mytemplate[QString::asprintf ("entry_%02d_name", i)] = QLatin1String("");
+			mytemplate[QString::asprintf ("entry_%02d_public_type", i)] = QLatin1String("");
+			mytemplate[QString::asprintf ("entry_%02d_private_type", i)] = QLatin1String("");
+			mytemplate[QString::asprintf ("entry_%02d_public", i)] = QLatin1String("");
+			mytemplate[QString::asprintf ("entry_%02d_private", i)] = QLatin1String("");
 			mytemplate[QString::asprintf ("entry_%02d_unlock_timeout", i)] = -1;
 			mytemplate[QString::asprintf ("entry_%02d_no_passphrase", i)] = false;
 		}
