@@ -251,7 +251,7 @@ public Q_SLOTS:
 		if(at == -1)
 			return out;
 		Item &i = items[at];
-		QList<KeyStoreEntryContext*> list = i.owner->entryList(i.storeContextId);
+		const QList<KeyStoreEntryContext*> list = i.owner->entryList(i.storeContextId);
 		for(int n = 0; n < list.count(); ++n)
 		{
 			KeyStoreEntry entry;
@@ -431,7 +431,7 @@ private:
 
 		QMutexLocker locker(&m);
 
-		QList<int> keyStores = c->keyStores();
+		const QList<int> keyStores = c->keyStores();
 
 		// remove any contexts that are gone
 		for(int n = 0; n < items.count(); ++n)
@@ -523,7 +523,7 @@ private Q_SLOTS:
 
 		busySources.remove(c);
 		bool changed = updateStores(c);
-		bool any_busy = !busySources.isEmpty();
+		const bool any_busy = !busySources.isEmpty();
 
 		if(!any_busy)
 		{
@@ -788,8 +788,8 @@ PGPKey KeyStoreEntry::pgpPublicKey() const
 
 bool KeyStoreEntry::ensureAvailable()
 {
-	QString storeId = this->storeId();
-	QString entryId = id();
+	const QString storeId = this->storeId();
+	const QString entryId = id();
 	KeyStoreEntryContext *c = (KeyStoreEntryContext *)trackercall("entry", QVariantList() << storeId << entryId).value<void*>();
 	if(c)
 		change(c);
@@ -803,7 +803,7 @@ bool KeyStoreEntry::ensureAccess()
 		d->accessible = false;
 		return false;
 	}
-	bool ok = static_cast<KeyStoreEntryContext *>(context())->ensureAccess();
+	const bool ok = static_cast<KeyStoreEntryContext *>(context())->ensureAccess();
 	d->accessible = ok;
 	return d->accessible;
 }
@@ -836,7 +836,7 @@ public:
 
 	void start()
 	{
-		QStringList list = ksm.keyStores();
+		const QStringList list = ksm.keyStores();
 		foreach(const QString &storeId, list)
 			ksm_available(storeId);
 	}
@@ -856,7 +856,7 @@ private Q_SLOTS:
 	void ks_updated()
 	{
 		bool found = false;
-		QList<KeyStoreEntry> list = ks->entryList();
+		const QList<KeyStoreEntry> list = ks->entryList();
 		foreach(const KeyStoreEntry &e, list)
 		{
 			if(e.id() == entryId && e.isAvailable())
@@ -1460,8 +1460,8 @@ public:
 		//   use QPointer here for full SS.
 		QPointer<QObject> self(this);
 
-		bool newbusy = KeyStoreTracker::instance()->isBusy();
-		QList<KeyStoreTracker::Item> newitems = KeyStoreTracker::instance()->getItems();
+		const bool newbusy = KeyStoreTracker::instance()->isBusy();
+		const QList<KeyStoreTracker::Item> newitems = KeyStoreTracker::instance()->getItems();
 
 		if(!busy && newbusy)
 		{
@@ -1515,7 +1515,7 @@ public:
 		// added
 		for(int n = 0; n < newitems.count(); ++n)
 		{
-			KeyStoreTracker::Item &i = newitems[n];
+			const KeyStoreTracker::Item &i = newitems[n];
 			bool found = false;
 			for(int k = 0; k < items.count(); ++k)
 			{
