@@ -411,7 +411,7 @@ public:
 			return;
 		}
 
-		Action a = actionQueue.takeFirst();
+		const Action a = actionQueue.takeFirst();
 
 		// set up for the next one, if necessary
 		if(!actionQueue.isEmpty() || need_update)
@@ -583,7 +583,7 @@ public:
 
 	void start_finished()
 	{
-		bool ok = c->result() == TLSContext::Success;
+		const bool ok = c->result() == TLSContext::Success;
 		if(!ok)
 		{
 			reset(ResetSession);
@@ -601,7 +601,7 @@ public:
 
 	void update_finished()
 	{
-		TLSContext::Result r = c->result();
+		const TLSContext::Result r = c->result();
 		if(r == TLSContext::Error)
 		{
 			if(state == Handshaking || state == Closing)
@@ -619,7 +619,7 @@ public:
 			return;
 		}
 
-		QByteArray c_to_net = c->to_net();
+		const QByteArray c_to_net = c->to_net();
 		if(!c_to_net.isEmpty())
 		{
 			QCA_logTextMessage(QStringLiteral("tls[%1]: to_net %2").arg(q->objectName(), QString::number(c_to_net.size())), Logger::Information);
@@ -691,13 +691,13 @@ public:
 		}
 		else // Connected
 		{
-			QByteArray c_to_app = c->to_app();
+			const QByteArray c_to_app = c->to_app();
 			if(!c_to_app.isEmpty())
 			{
 				QCA_logTextMessage(QStringLiteral("tls[%1]: to_app %2").arg(q->objectName(), QString::number(c_to_app.size())), Logger::Information);
 			}
 
-			bool eof = c->eof();
+			const bool eof = c->eof();
 			int enc = -1;
 			if(!c_to_net.isEmpty())
 				enc = c->encoded();
@@ -1082,7 +1082,7 @@ QByteArray TLS::read()
 {
 	if(d->mode == Stream)
 	{
-		QByteArray a = d->in;
+		const QByteArray a = d->in;
 		d->in.clear();
 		return a;
 	}
@@ -1109,7 +1109,7 @@ QByteArray TLS::readOutgoing(int *plainBytes)
 {
 	if(d->mode == Stream)
 	{
-		QByteArray a = d->to_net;
+		const QByteArray a = d->to_net;
 		d->to_net.clear();
 		if(plainBytes)
 			*plainBytes = d->to_net_encoded;
@@ -1121,8 +1121,8 @@ QByteArray TLS::readOutgoing(int *plainBytes)
 	{
 		if(!d->packet_to_net.isEmpty())
 		{
-			QByteArray a = d->packet_to_net.takeFirst();
-			int x = d->packet_to_net_encoded.takeFirst();
+			const QByteArray a = d->packet_to_net.takeFirst();
+			const int x = d->packet_to_net_encoded.takeFirst();
 			if(plainBytes)
 				*plainBytes = x;
 			return a;
@@ -1140,7 +1140,7 @@ QByteArray TLS::readUnprocessed()
 {
 	if(d->mode == Stream)
 	{
-		QByteArray a = d->unprocessed;
+		const QByteArray a = d->unprocessed;
 		d->unprocessed.clear();
 		return a;
 	}
@@ -1515,7 +1515,7 @@ public:
 			return;
 		}
 
-		Action a = actionQueue.takeFirst();
+		const Action a = actionQueue.takeFirst();
 
 		// set up for the next one, if necessary
 		if(!actionQueue.isEmpty() || need_update)
@@ -1599,7 +1599,7 @@ private Q_SLOTS:
 		int last_op = op;
 		op = -1;
 
-		SASLContext::Result r = c->result();
+		const SASLContext::Result r = c->result();
 
 		if(last_op == OpStart)
 		{
@@ -1680,7 +1680,7 @@ private Q_SLOTS:
 					}
 					else if(r == SASLContext::Params)
 					{
-						Params np = c->clientParams();
+						const Params np = c->clientParams();
 						emit q->needParams(np);
 						return;
 					}
@@ -1703,7 +1703,7 @@ private Q_SLOTS:
 					}
 					else if(r == SASLContext::Params)
 					{
-						Params np = c->clientParams();
+						const Params np = c->clientParams();
 						emit q->needParams(np);
 						return;
 					}
@@ -1732,8 +1732,8 @@ private Q_SLOTS:
 				return;
 			}
 
-			QByteArray c_to_net = c->to_net();
-			QByteArray c_to_app = c->to_app();
+			const QByteArray c_to_net = c->to_net();
+			const QByteArray c_to_app = c->to_app();
 			int enc = -1;
 			if(!c_to_net.isEmpty())
 				enc = c->encoded();
@@ -1959,7 +1959,7 @@ void SASL::write(const QByteArray &a)
 
 QByteArray SASL::read()
 {
-	QByteArray a = d->in;
+	const QByteArray a = d->in;
 	d->in.clear();
 	return a;
 }
@@ -1972,7 +1972,7 @@ void SASL::writeIncoming(const QByteArray &a)
 
 QByteArray SASL::readOutgoing(int *plainBytes)
 {
-	QByteArray a = d->to_net;
+	const QByteArray a = d->to_net;
 	d->to_net.clear();
 	if(plainBytes)
 		*plainBytes = d->to_net_encoded;
