@@ -147,7 +147,7 @@ void *qca_secure_alloc(int bytes)
 {
 	// allocate enough room to store a size value in front, return a pointer after it
 	char *c = (char *)QCA::botan_secure_alloc(bytes + sizeof(int));
-	((int *)c)[0] = bytes + sizeof(int);
+	reinterpret_cast<int *>(c)[0] = bytes + sizeof(int);
 	return c + sizeof(int);
 }
 
@@ -156,7 +156,7 @@ void qca_secure_free(void *p)
 	// backtrack to read the size value
 	char *c = (char *)p;
 	c -= sizeof(int);
-	int bytes = ((int *)c)[0];
+	const int bytes = reinterpret_cast<int *>(c)[0];
 	QCA::botan_secure_free(c, bytes);
 }
 
@@ -169,7 +169,7 @@ void *qca_secure_realloc(void *p, int bytes)
 	// backtrack to read the size value
 	char *c = (char *)p;
 	c -= sizeof(int);
-	int oldsize = ((int *)c)[0] - sizeof(int);
+	const int oldsize = reinterpret_cast<int *>(c)[0] - sizeof(int);
 
 	// alloc the new chunk
 	char *new_p = (char *)qca_secure_alloc(bytes);
@@ -710,7 +710,7 @@ QByteArray SecureArray::toByteArray() const
 
 SecureArray & SecureArray::append(const SecureArray &a)
 {
-	int oldsize = size();
+	const int oldsize = size();
 	resize(oldsize + a.size());
 	memcpy(data() + oldsize, a.data(), a.size());
 	return *this;
@@ -732,7 +732,7 @@ SecureArray & SecureArray::operator+=(const SecureArray &a)
 
 void SecureArray::fill(char fillChar, int fillToPosition)
 {
-	int len = (fillToPosition == -1) ? size() : qMin(fillToPosition, size());
+	const int len = (fillToPosition == -1) ? size() : qMin(fillToPosition, size());
 	if(len > 0)
 		memset(data(), (int)fillChar, len);
 }
@@ -805,7 +805,7 @@ BigInteger::BigInteger(int i)
 BigInteger::BigInteger(const char *c)
 {
 	d = new Private;
-	fromString(QString(c));
+	fromString(QString::fromLatin1(c));
 }
 
 BigInteger::BigInteger(const QString &s)
@@ -967,7 +967,7 @@ QString BigInteger::toString() const
 
 	QString str;
 	if(d->n.is_negative())
-		str += '-';
+		str += QLatin1Char('-');
 	str += QString::fromLatin1(cs);
 	return str;
 }
@@ -976,10 +976,10 @@ bool BigInteger::fromString(const QString &s)
 {
 	if(s.isEmpty())
 		return false;
-	QByteArray cs = s.toLatin1();
+	const QByteArray cs = s.toLatin1();
 
 	bool neg = false;
-	if(s[0] == '-')
+	if(s[0] == QLatin1Char('-'))
 		neg = true;
 
 	try
