@@ -640,8 +640,8 @@ bool ConsoleReference::start(Console *console, SecurityMode mode)
 	d->thread = d->console->d->thread;
 	d->console->d->ref = this;
 
-	bool valid = d->thread->isValid();
-	int avail = d->thread->bytesAvailable();
+	const bool valid = d->thread->isValid();
+	const int avail = d->thread->bytesAvailable();
 
 	// pipe already closed and no data?  consider this an error
 	if(!valid && avail == 0)
@@ -826,7 +826,7 @@ public:
 		}
 
 		if(!charMode)
-			writeString(promptStr + ": ");
+			writeString(promptStr + QStringLiteral(": "));
 
 		return true;
 	}
@@ -847,14 +847,14 @@ public:
 			return false;
 		}
 
-		if(c == '\r' || c == '\n')
+		if(c == QLatin1Char('\r') || c == QLatin1Char('\n'))
 		{
 			writeString(QStringLiteral("\n"));
 			done = true;
 			return false;
 		}
 
-		if(c == '\b' || c.unicode() == 0x7f)
+		if(c == QLatin1Char('\b') || c.unicode() == 0x7f)
 		{
 			if(at > 0)
 			{
@@ -880,7 +880,7 @@ public:
 	{
 		if((at + 1) * (int)sizeof(ushort) > result.size())
 			result.resize((at + 1) * sizeof(ushort));
-		ushort *p = (ushort *)result.data();
+		ushort *p = reinterpret_cast<ushort *>(result.data());
 		p[at++] = c.unicode();
 	}
 
@@ -890,8 +890,8 @@ public:
 		QTextCodec *codec = QTextCodec::codecForMib(106);
 		QTextCodec::ConverterState cstate(QTextCodec::IgnoreHeader);
 		SecureArray out;
-		ushort *ustr = (ushort *)result.data();
-		int len = result.size() / sizeof(ushort);
+		const ushort *ustr = reinterpret_cast<ushort *>(result.data());
+		const int len = result.size() / sizeof(ushort);
 		for(int n = 0; n < len; ++n)
 		{
 			QChar c(ustr[n]);
@@ -1010,7 +1010,7 @@ SecureArray ConsolePrompt::result() const
 
 QChar ConsolePrompt::resultChar() const
 {
-	QString str = QString::fromUtf8(d->result.toByteArray());
+	const QString str = QString::fromUtf8(d->result.toByteArray());
 
 	// this will never happen if getChar completes
 	if(str.isEmpty())
