@@ -219,7 +219,7 @@ void HashUnitTest::md5filetest()
 {
     foreach(QString provider, providersToTest) {
 	if(!QCA::isSupported("md5", provider)) {
-	    QFile f1( TEST_DATA_DIR "/data/empty" );
+	    QFile f1( QStringLiteral(TEST_DATA_DIR "/data/empty") );
 	    QVERIFY( f1.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("md5"), provider);
@@ -228,7 +228,7 @@ void HashUnitTest::md5filetest()
 			    QStringLiteral( "d41d8cd98f00b204e9800998ecf8427e" ) );
 	    }
 
-	    QFile f2( TEST_DATA_DIR "/data/twobytes" );
+	    QFile f2( QStringLiteral(TEST_DATA_DIR "/data/twobytes") );
 	    QVERIFY( f2.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("md5"), provider);
@@ -238,7 +238,7 @@ void HashUnitTest::md5filetest()
 	    }
 
 
-	    QFile f3( TEST_DATA_DIR "/data/twohundredbytes" );
+	    QFile f3( QStringLiteral(TEST_DATA_DIR "/data/twohundredbytes") );
 	    QVERIFY( f3.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("md5"), provider);
@@ -368,7 +368,7 @@ void HashUnitTest::sha1longtest()
 	    QCOMPARE( QString(QCA::arrayToHex(shaHash.final().toByteArray())),
 		     QStringLiteral("34aa973cd4c4daa4f61eeb2bdbad27316534016f") );
 
-	    QFile f1( TEST_DATA_DIR "/data/empty" );
+	    QFile f1( QStringLiteral(TEST_DATA_DIR "/data/empty") );
 	    QVERIFY( f1.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("sha1"), provider);
@@ -377,7 +377,7 @@ void HashUnitTest::sha1longtest()
 			    QStringLiteral( "da39a3ee5e6b4b0d3255bfef95601890afd80709" ) );
 	    }
 
-	    QFile f2( TEST_DATA_DIR "/data/twobytes" );
+	    QFile f2( QStringLiteral(TEST_DATA_DIR "/data/twobytes") );
 	    QVERIFY( f2.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("sha1"), provider);
@@ -386,7 +386,7 @@ void HashUnitTest::sha1longtest()
 			    QStringLiteral( "efbd6de3c51ca16094391e837bf52f7452593e5c" ) );
 	    }
 
-	    QFile f3( TEST_DATA_DIR "/data/twohundredbytes" );
+	    QFile f3( QStringLiteral(TEST_DATA_DIR "/data/twohundredbytes") );
 	    QVERIFY( f3.open( QIODevice::ReadOnly ) );
 	    {
 		QCA::Hash hashObj(QStringLiteral("sha1"), provider);
